@@ -2,62 +2,39 @@
 
 /**
   * SquirrelMail Empty Folders Plugin
-  * Copyright (C) 2003, 2004 Paul Lesneiwski <pdontthink@angrynerds.com>
+  * Copyright (C) 2003-2005 Paul Lesneiwski <pdontthink@angrynerds.com>
   * This program is licensed under GPL. See COPYING for details
   *
+  * @package plugins
+  * @subpackage Empty Folders
+  *
   */
 
 
-chdir('..');
-define('SM_PATH','../');
+
+if (!defined('SM_PATH')) define('SM_PATH', '../../');
 
 
 
-// include compatibility plugin
-//
-if (defined('SM_PATH'))
-   include_once(SM_PATH . 'plugins/compatibility/functions.php');
-else if (file_exists('../plugins/compatibility/functions.php'))
-   include_once('../plugins/compatibility/functions.php');
-else if (file_exists('./plugins/compatibility/functions.php'))
-   include_once('./plugins/compatibility/functions.php');
-
-
-
-if (compatibility_check_sm_version(1, 3))
-{
-   include_once (SM_PATH . 'include/validate.php');
-   include_once (SM_PATH . 'functions/imap.php');
-}
+if (file_exists(SM_PATH . 'include/validate.php'))
+   include_once(SM_PATH . 'include/validate.php');
 else
-{
-   include_once ('../src/validate.php');
-   include_once ('../functions/imap.php');
-}
+   include_once(SM_PATH . 'src/validate.php');
 
 
-if (compatibility_check_sm_version(1, 3))
-   include_once (SM_PATH . 'plugins/empty_folders/config.php');
-else
-   include_once ('../plugins/empty_folders/config.php');
+include_once (SM_PATH . 'functions/imap.php');
+load_config('empty_folders', array('config.php.sample', 'config.php'));
 
 
 global $imapServerAddress, $imapPort, $username, $key, $move_to_trash;
 
 
-// get global variable for versions of PHP < 4.1
-//
-if (!compatibility_check_php_version(4,1)) {
-   global $HTTP_COOKIE_VARS;
-   $_COOKIE = $HTTP_COOKIE_VARS;
-}
+sqgetGlobalVar('username', $username, SQ_SESSION);
+sqgetGlobalVar('key', $key, SQ_COOKIE);
+sqgetGlobalVar('delimiter', $delimiter, SQ_SESSION);
+sqgetGlobalVar('onetimepad', $onetimepad, SQ_SESSION);
 
-$key = $_COOKIE['key'];
-compatibility_sqextractGlobalVar('username');
-compatibility_sqextractGlobalVar('delimiter');
-compatibility_sqextractGlobalVar('onetimepad');
-
-compatibility_sqextractGlobalVar('mailbox');
+sqgetGlobalVar('mailbox', $mailbox, SQ_FORM);
 if (isset($mailbox)){
     $mailbox = urldecode( $mailbox );
 }
@@ -78,7 +55,7 @@ $imap_stream = sqimap_login($username, $key, $imapServerAddress, $imapPort, 0);
 
 // figure out if there are any messages to delete
 //
-if (compatibility_check_sm_version(1, 3)) 
+if (check_sm_version(1, 3)) 
 {
    $mbx_response = sqimap_mailbox_select($imap_stream, $mailbox);
    $mbx_response = $mbx_response['EXISTS'];
@@ -118,7 +95,8 @@ if ($mbx_response > 0) {
 }
 
 
-header ('Location: ' . SM_PATH . '../src/left_main.php');
+$base_uri = sqm_baseuri();
+header ('Location: ' . $base_uri . 'src/left_main.php');
 
 sqimap_logout($imap_stream);
 
