@@ -2,26 +2,26 @@
 
 /**
   * SquirrelMail Empty Folders Plugin
-  * Copyright (C) 2003, 2004 Paul Lesneiwski <pdontthink@angrynerds.com>
+  * Copyright (C) 2003-2005 Paul Lesneiwski <pdontthink@angrynerds.com>
   * This program is licensed under GPL. See COPYING for details
   *
+  * @package plugins
+  * @subpackage Empty Folders
+  *
   */
 
 
-   // include compatibility plugin
-   //
-   if (defined('SM_PATH'))
-      include_once(SM_PATH . 'plugins/compatibility/functions.php');
-   else if (file_exists('../plugins/compatibility/functions.php'))
-      include_once('../plugins/compatibility/functions.php');
-   else if (file_exists('./plugins/compatibility/functions.php'))
-      include_once('./plugins/compatibility/functions.php');
 
-
-
-// Display empty links on target folders
-//
-function empty_folders_show_link_do($parms) {
+/**
+  * Display empty links on target folders
+  *
+  * @param array $parms Parameters passed to this hook by SquirrelMail - 
+  *                     First element is number of messages, second is
+  *                     mailbox name, third is a usable IMAP server connection.
+  *                     
+  */
+function empty_folders_show_link_do($parms) 
+{
 
    global $data_dir, $username, $default_folders_to_show_empty_link;
    $numMessages = $parms[0];
@@ -29,11 +29,7 @@ function empty_folders_show_link_do($parms) {
    $imapConnection = $parms[2];
 
 
-   if (!defined('SM_PATH'))
-      define('SM_PATH', '../');
-
-
-   include_once (SM_PATH . 'plugins/empty_folders/config.php');
+   load_config('empty_folders', array('config.php.sample', 'config.php'));
 
 
    // grab preferences
@@ -55,7 +51,7 @@ function empty_folders_show_link_do($parms) {
       $numMessages = sqimap_get_num_messages($imapConnection, $real_box);
    }
    if ($numMessages > 0 && in_array($real_box, $empty_folders_show_link)) {
-      bindtextdomain('empty_folders', SM_PATH . 'plugins/empty_folders/locale');
+      bindtextdomain('empty_folders', SM_PATH . 'locale');
       textdomain('empty_folders');
       $urlMailbox = urlencode($real_box);
       $text = "<small>&nbsp;&nbsp;(<A HREF=\"../plugins/empty_folders/empty_folder.php?mailbox=$urlMailbox\" style=\"text-decoration:none\">"._("empty")."</A>)</small>";
@@ -68,9 +64,12 @@ function empty_folders_show_link_do($parms) {
 
 
 
-// This is the text that appears on the option page
-//
-function empty_folders_show_options_do() {
+/**
+  * Places text and widgets on the option page
+  *
+  */
+function empty_folders_show_options_do() 
+{
 
    global $username, $data_dir, $color, $user_empty_link, 
           $user_empty_behavior, $default_empty_link_behavior,
@@ -80,21 +79,21 @@ function empty_folders_show_options_do() {
    // grab new settings if user had just pressed Save
    //
    global $empty_folders_form;
-   compatibility_sqextractGlobalVar('empty_folders_form');
+   sqgetGlobalVar('empty_folders_form', $empty_folders_form, SQ_FORM);
    if (isset($empty_folders_form) && $empty_folders_form)
    {
 
       // get behavior first; it's easy
       //
       global $empty_folders_link_behavior;
-      compatibility_sqextractGlobalVar('empty_folders_link_behavior');
+      sqgetGlobalVar('empty_folders_link_behavior', $empty_folders_link_behavior, SQ_FORM);
       setPref($data_dir, $username, 'empty_folders_link_behavior', $empty_folders_link_behavior);
       
 
       // get folders that should get an empty link
       //
       global $empty_folders_show_link;
-      compatibility_sqextractGlobalVar('empty_folders_show_link');
+      sqgetGlobalVar('empty_folders_show_link', $empty_folders_show_link, SQ_FORM);
       $allFolders = '';
       if (isset($empty_folders_show_link))
          foreach ($empty_folders_show_link as $folder)
@@ -106,10 +105,7 @@ function empty_folders_show_options_do() {
    }
 
 
-   if (!defined('SM_PATH'))
-      define('SM_PATH', '../');
-
-   include_once (SM_PATH . 'plugins/empty_folders/config.php');
+   load_config('empty_folders', array('config.php.sample', 'config.php'));
 
 
    // grab preferences
@@ -131,7 +127,7 @@ function empty_folders_show_options_do() {
    
    $empty_folders_show_link = explode('###', $allFolders);
 
-   bindtextdomain('empty_folders', SM_PATH . 'plugins/empty_folders/locale');
+   bindtextdomain('empty_folders', SM_PATH . 'locale');
    textdomain('empty_folders');
 
    if ($user_empty_link || $user_empty_behavior)
